# Truecaser

A set of language modeling tools that can be used to predict and restore text based case information.

## Prerequisites
- Python 3
- [crfsuite](https://github.com/downloads/chokkan/crfsuite/crfsuite-0.12-x86_64.tar.gz)


## Installing
`pip install truecaser`
or
`python3 -m pip install truecaser`

## Usage
`python3 -m truecase [args]`


